@@ -271,7 +271,7 @@ void thread::invite(void)
 	osip_header_t *msgheader = NULL;
 	char fromext[32];
 	cdr *cdrnode;
-	const char *domain = stack::sip.domain;
+	const char *domain = registry::getDomain();
 
 	uri::serviceid(requesting, call->request, sizeof(call->request));
 
@@ -292,19 +292,7 @@ void thread::invite(void)
 		call->failed(this, session);
 		return;
 	}
-
-	// FIXME: we should get proxy count extimate from sdp into global thread object...
-
-	// assign initial proxy if required to accept call...
-	// if no proxy available, then return 503...
-//	if(server::classify(&session->proxy, &call->source->proxy, via_address.getAddr())) {
-//		if(!stack::assign(call, 4)) 
-//			goto noproxy;
-//	}
-//	else 
-//	if((destination == REDIRECTED || destination == EXTERNAL) && server::isProxied() && !stack::assign(call, 4))
-//		goto noproxy;
-		
+	
 	if(extension)
 		snprintf(fromext, sizeof(fromext), "%u", extension);
 
@@ -442,8 +430,14 @@ void thread::invite(void)
 		else
 			String::set(session->display, sizeof(session->display), identity);
 
-		snprintf(session->identity, sizeof(session->identity), "%s:%s@%s",
-			stack::sip.getScheme(), session->sysident, domain);
+		if(registry::getDomain() || destination != EXTERNAL) 
+			snprintf(session->identity, sizeof(session->identity), "%s:%s@%s",
+				stack::sip.getScheme(), session->sysident, domain);
+		else {
+			gethostname(buftemp, sizeof(buftemp));
+			snprintf(session->identity, sizeof(session->identity), "%s:%s@%s",
+				stack::sip.getScheme(), session->sysident, buftemp);	
+		}
 
 		if(destination == EXTERNAL)
 			uri::identity(request_address.getAddr(), call->dialed, uri->username, sizeof(call->dialed));
@@ -636,6 +630,8 @@ bool thread::authorize(void)
 	const char *refer = NULL;
 	const char *uri_host;
 	struct sockaddr_internet iface;
+	osip_header_t *msgheader = NULL;
+	bool anon = false;
 
 	if(!sevent->request || !sevent->request->to || !sevent->request->from || !sevent->request->req_uri)
 		goto invalid;
@@ -645,14 +641,19 @@ bool thread::authorize(void)
 	uri = sevent->request->req_uri;
 	to = sevent->request->to;
 	uri_host = uri->host;
+	
+	osip_message_header_get_byname(sevent->request, P_SIPWITCH_NODE, 0, &msgheader);
+	if(msgheader && msgheader->hvalue)
+		if(!stricmp(msgheader->hvalue, "no") || !strnicmp(msgheader->hvalue, "anon", 4))
+			anon = true; 
 
 	error = SIP_ADDRESS_INCOMPLETE;
 
 	if(stack::sip_tlsmode)
 		scheme = "sips";
 
-	if(!uri_host && stack::sip.domain)
-		uri_host = (char *)stack::sip.domain;
+	if(!uri_host && registry::getDomain())
+		uri_host = (char *)registry::getDomain();
 
 	if(!from->url->host || !uri_host)
 		goto invalid;
@@ -707,11 +708,15 @@ bool thread::authorize(void)
 		uri->scheme, uri->username, uri_host, local_port,
 		to->url->scheme, to->url->username, to->url->host, to_port);
 */
-	// bypass request address processing if local domain call....
 
+	// if marked as a remote call, we can skip local tests entirely
+	if(anon)
+		goto remote;
+
+	// bypass request address processing if local domain call....
 	memset(&iface, 0, sizeof(iface));
 
-	if(String::equal(stack::sip.domain, uri_host))
+	if(String::equal(registry::getRealm(), uri_host))
 		goto local;
 
 	if(String::equal("localdomain", uri_host))
@@ -845,7 +850,7 @@ trying:
 		// associated with us.  If it has any of our our names, then we have
 		// the inbound caller authenticate like any local-to-local call
 
-		if(String::equal(stack::sip.domain, from->url->host))
+		if(String::equal(registry::getRealm(), from->url->host))
 			return authenticate();
 
 		if(String::equal("localdomain", from->url->host))
@@ -1184,7 +1189,7 @@ bool thread::authenticate(void)
 	// one doesn't want to loose configuration info
 
 	if(!stricmp(node->getId(), "reject")) {
-		process::errlog(NOTICE, "rejecting unauthorized %s", auth->username);
+		process::errlog(NOTICE, "rejecting user %s", auth->username);
 		error = SIP_FORBIDDEN;
 		cp = service::getValue(node, "error");
 		if(cp)
@@ -1876,8 +1881,12 @@ void thread::run(void)
 			// copy target sdp into session object...
 			body = NULL;
 			osip_message_get_body(sevent->response, 0, &body);
-			if(body && body->body)
-				String::set(session->sdp, sizeof(session->sdp), body->body);
+			if(body && body->body) {
+				if(media::answer(session, body->body) == NULL) {
+					session->parent->failed(this, session);
+					break;
+				}
+			}
 			session->parent->answer(this, session);
 			break;
 		case EXOSIP_CALL_SERVERFAILURE:
