@@ -429,6 +429,7 @@ static void usage(void)
         "  concurrency <level>     Server concurrency level\n"
 		"  down                    Shut down server\n"
 		"  dump                    Dump server configuration\n"
+		"  history [bufsize]       Set buffer or dump error log\n"
 		"  message <ext> <text>    Send text message to extension\n"
 		"  period <interval>       Collect periodic statistics\n"
 		"  pstats                  Dump periodic statistics\n"
@@ -436,10 +437,12 @@ static void usage(void)
         "  release <ext>           Release registration\n"
 		"  reload                  Reload configuration\n"
         "  restart                 Server restart\n"
+		"  siplog                  Dump sip log when tracing\n"
         "  snapshot                Server snapshot\n"
         "  stats                   Dump server statistics\n"
         "  state <selection>       Change server state\n"
 		"  status                  Dump status string\n"
+		"  trace <on|off|clear>    Set sip message tracing\n"
         "  verbose <level>         Server verbose logging level\n"
 	);		
 
@@ -576,11 +579,17 @@ extern "C" int main(int argc, char **argv)
 		version();
 	else if(String::equal(*argv, "help") || String::equal(*argv, "-help") || String::equal(*argv, "--help"))
 		usage();
-	else if(String::equal(*argv, "reload") || String::equal(*argv, "check") || String::equal(*argv, "snapshot") || String::equal(*argv, "dump"))
+	else if(String::equal(*argv, "reload") || String::equal(*argv, "check") || String::equal(*argv, "snapshot") || String::equal(*argv, "dump") || String::equal(*argv, "siplog"))
 		single(argv, 30);
+	else if(String::equal(*argv, "history")) {
+		if(argc == 2)
+			single(argv, 30);
+		else
+			level(argv, 10);
+	}
 	else if(String::equal(*argv, "down") || String::equal(*argv, "restart") || String::equal(*argv, "abort"))
 		single(argv, 0);
-	else if(String::equal(*argv, "verbose") || String::equal(*argv, "concurrency"))
+	else if(String::equal(*argv, "verbose") || String::equal(*argv, "concurrency") || String::equal(*argv, "trace"))
 		level(argv, 10);
 	else if(String::equal(*argv, "message"))
 		message(argv);
